@@ -1,5 +1,5 @@
 package Data::Perl::String::MooseLike;
-$Data::Perl::String::MooseLike::VERSION = '0.001006';
+$Data::Perl::String::MooseLike::VERSION = '0.001007';
 # ABSTRACT: data::Perl::String subclass that simulates Moose's native traits.
 
 use strictures 1;
@@ -29,51 +29,23 @@ Data::Perl::String::MooseLike - data::Perl::String subclass that simulates Moose
 
 =head1 VERSION
 
-version 0.001006
+version 0.001007
 
 =head1 SYNOPSIS
 
-  use Data::Perl::Collection::Hash::MooseLike;
+  use Data::Perl::Collection::String::MooseLike;
 
-  my $hash = Data::Perl::Collection::Hash::MooseLike->new(a => 1, b => 2);
+  my $string = Data::Perl::Collection::String::MooseLike->new("this is a string\n");
 
-  $hash->values; # (1, 2)
+  $string->chomp;
 
-  $hash->set('foo', 'bar'); # (a => 1, b => 2, foo => 'bar')
+  $string->substr(); # etc
 
 =head1 DESCRIPTION
 
-This class provides a wrapper and methods for interacting with a hash.  All
+This class provides a wrapper and methods for interacting with a string. All
 methods are written to emulate/match existing behavior that exists with Moose's
-native traits.
-
-=head1 DIFFERENCES IN FUNCTIONALITY
-
-=over 4
-
-=item B<get($key, $key, ...)>
-
-Returns values from the hash.
-
-In list context it returns a list of values in the hash for the given keys. In
-scalar context it returns the value for the last key specified.
-
-=item B<set($key, $value, ...)>
-
-Sets the elements in the hash to the given values. It returns the new values
-set for each key, in the same order as the keys passed to the method.
-
-This method requires at least two arguments, and expects an even number of
-arguments.
-
-=item B<delete($key, $key, ...)>
-
-Removes the elements with the given keys.
-
-In list context it returns a list of values in the hash for the deleted keys.
-In scalar context it returns the value for the last key specified.
-
-=back
+native traits. You should probably be looking at Data::Perl's documentation instead.
 
 =head1 SEE ALSO
 
